@@ -11,7 +11,7 @@ from .enums import (
     CongestionSeriesSplit,
     CongestionSeriesUnit,
     CongestionVesselsOperation,
-    ContractTypes,
+    ContractsTypes,
     FleetDevelopmentSeriesAggregationMetric,
     FleetDevelopmentSeriesMetric,
     FleetDevelopmentSeriesPeriod,
@@ -19,12 +19,12 @@ from .enums import (
     FleetDevelopmentSeriesUnit,
     FleetDevelopmentVesselsComplianceMethods,
     FleetDevelopmentVesselsMetric,
-    FleetMetricAlgo,
-    FleetMetricMeasurementUnit,
-    FleetMetricPeriod,
-    FleetMetricSplit,
-    FleetMetricVesselsAlgo,
-    FleetMetricVesselsMeasurementUnit,
+    FleetMetricsAlgo,
+    FleetMetricsMeasurementUnit,
+    FleetMetricsPeriod,
+    FleetMetricsSplit,
+    FleetMetricsVesselsAlgo,
+    FleetMetricsVesselsMeasurementUnit,
     FleetUtilizationSeriesMetric,
     FleetUtilizationSeriesPeriod,
     FleetUtilizationSeriesSplit,
@@ -32,20 +32,20 @@ from .enums import (
     FleetUtilizationSeriesVesselsState,
     FleetUtilizationVesselsState,
     FleetUtilizationVesselsUnit,
-    FlowDirection,
-    FlowMeasurementUnit,
-    FlowPeriod,
-    FlowSplit,
-    FreightMetricSeriesMetric,
-    FreightMetricSeriesPeriod,
-    FreightMetricSeriesSplit,
-    FreightMetricSeriesUnit,
+    FlowsDirection,
+    FlowsMeasurementUnit,
+    FlowsPeriod,
+    FlowsSplit,
+    FreightMetricsSeriesMetric,
+    FreightMetricsSeriesPeriod,
+    FreightMetricsSeriesSplit,
+    FreightMetricsSeriesUnit,
     InventoriesPeriod,
     InventoriesSplit,
-    OutageTypes,
+    OutagesTypes,
     Platform,
-    PriceIndexes,
-    TradeStatus,
+    PricesIndexes,
+    TradesStatus,
     VesselTypesCPP,
     VesselTypesDry,
     VesselTypesLNG,
@@ -69,24 +69,24 @@ __all__ = [
     "CongestionSeriesUnit",
     "CongestionVesselsOperation",
     "Platform",
-    "TradeStatus",
+    "TradesStatus",
     "FleetDevelopmentVesselsComplianceMethods",
     "FleetDevelopmentVesselsMetric",
-    "FlowDirection",
-    "FlowPeriod",
-    "FlowSplit",
-    "FlowMeasurementUnit",
+    "FlowsDirection",
+    "FlowsPeriod",
+    "FlowsSplit",
+    "FlowsMeasurementUnit",
     "FleetDevelopmentSeriesAggregationMetric",
     "FleetDevelopmentSeriesMetric",
     "FleetDevelopmentSeriesPeriod",
     "FleetDevelopmentSeriesSplit",
     "FleetDevelopmentSeriesUnit",
-    "FleetMetricPeriod",
-    "FleetMetricMeasurementUnit",
-    "FleetMetricAlgo",
-    "FleetMetricSplit",
-    "FleetMetricVesselsAlgo",
-    "FleetMetricVesselsMeasurementUnit",
+    "FleetMetricsPeriod",
+    "FleetMetricsMeasurementUnit",
+    "FleetMetricsAlgo",
+    "FleetMetricsSplit",
+    "FleetMetricsVesselsAlgo",
+    "FleetMetricsVesselsMeasurementUnit",
     "FleetUtilizationSeriesMetric",
     "FleetUtilizationSeriesPeriod",
     "FleetUtilizationSeriesSplit",
@@ -94,13 +94,13 @@ __all__ = [
     "FleetUtilizationSeriesVesselsState",
     "FleetUtilizationVesselsState",
     "FleetUtilizationVesselsUnit",
-    "OutageTypes",
-    "PriceIndexes",
-    "ContractTypes",
-    "FreightMetricSeriesPeriod",
-    "FreightMetricSeriesSplit",
-    "FreightMetricSeriesUnit",
-    "FreightMetricSeriesMetric",
+    "OutagesTypes",
+    "PricesIndexes",
+    "ContractsTypes",
+    "FreightMetricsSeriesPeriod",
+    "FreightMetricsSeriesSplit",
+    "FreightMetricsSeriesUnit",
+    "FreightMetricsSeriesMetric",
     "VesselTypesCPP",
     "VesselTypesOil",
     "VesselTypesDry",
